%%
%% This is file `skbbook.cls',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% skb.dtx  (with options: `skbbook')
%% 
%% 
%% skbbook.cls
%% Copyright (c) 2011 Sven van der Meer <sven@vandermeer.de>
%%
%% This work may be distributed  and/or modified under the conditions  of the
%% LaTeX Project Public  License, either version  1.3 of this  license or (at
%% your option) any later version.
%% The latest version of this license is in
%%    <http://www.latex-project.org/lppl.txt>
%% and version 1.3  or later is  part of all  distributions of LaTeX  version
%% 2005/12/01 or later.
%%
%% This work has the LPPL maintenance status `author-maintained'.
%%
%% The Current Maintainer of this work is
%%    Sven van der Meer <sven@vandermeer.de>
%%
%% This software is  provided 'as is',  without warranty of  any kind, either
%% expressed  or  implied,  including,  but  not  limited  to,  the   implied
%% warranties of merchantability and fitness for a particular purpose.
%%
%% This work consists of all files listed in MANIFEST.TXT.
%%
\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{skbbook}[2011/06/03 The SKB Book class v0.52]
\LoadClass[11pt,a4paper,extrafontsizes,twoside,onecolumn,openright]{memoir}
\RequirePackage{skb}
\RequirePackage[style=alphabetic,sorting=none,hyperref]{biblatex}
\RequirePackage[printonlyused]{acronym}
\RequirePackage{etoolbox,comment,graphicx,longtable,colortbl}
\RequirePackage{textcomp,gensymb,wasysym,units,xmpmulti,float}
\RequirePackage[x11names]{xcolor}
\RequirePackage[colorlinks,%
                linkcolor=Brown4,%
                citecolor=SeaGreen4,%
                urlcolor=RoyalBlue3%
               ]{hyperref}
\headstyles{komalike}
\setlength{\oddsidemargin}{.5cm}
\setlength{\evensidemargin}{0cm}
\setlength{\textwidth}{15cm}
\setlength{\textheight}{22cm}
\setlength{\topmargin}{-.5cm}
\settocdepth{subsubsection}
\setsecnumdepth{subsubsection}
\tightlists
\midsloppy
\raggedbottom
\chapterstyle{veelo}
\ExecuteBibliographyOptions{sorting=anyt}
\endinput
%%
%% End of file `skbbook.cls'.
